@@ -1,7 +1,7 @@
 from pathlib import Path
 
 import pytest  # type: ignore
-from ape import Project, networks
+from ape import Project, accounts, networks
 from ape.api.networks import LOCAL_NETWORK_NAME, NetworkAPI
 from ape.managers.project import ProjectManager
 
@@ -22,6 +22,26 @@ def get_hardhat_provider(network_api: NetworkAPI):
     )
 
 
+@pytest.fixture
+def test_accounts():
+    return accounts.test_accounts
+
+
+@pytest.fixture
+def sender(test_accounts):
+    return test_accounts[0]
+
+
+@pytest.fixture
+def receiver(test_accounts):
+    return test_accounts[1]
+
+
+@pytest.fixture
+def owner(test_accounts):
+    return test_accounts[2]
+
+
 @pytest.fixture(scope="session")
 def project():
     return get_project()
@@ -43,6 +63,7 @@ def hardhat_connected(network_api):
     provider = get_hardhat_provider(network_api)
     provider.port = "auto"  # For better multi-processing support
     provider.connect()
+    networks.active_provider = provider
     try:
         yield provider
     finally:
